@@ -15,14 +15,9 @@ load(system.file("extdata", "results_vignette_kfunc.rda",
 library(spNetwork)
 library(tmap)
 
-networkgpkg <- system.file("extdata", "networks.gpkg",
-                           package = "spNetwork", mustWork = TRUE)
-eventsgpkg <- system.file("extdata", "events.gpkg",
-                          package = "spNetwork", mustWork = TRUE)
-
-main_network_mtl <- sf::st_read(networkgpkg,layer="main_network_mtl", quiet = TRUE)
-mtl_libraries <- sf::st_read(eventsgpkg,layer="mtl_libraries", quiet = TRUE)
-mtl_theatres <- sf::st_read(eventsgpkg,layer="mtl_theatres", quiet = TRUE)
+data(main_network_mtl)
+data(mtl_libraries)
+data(mtl_theatres)
 
 tm_shape(main_network_mtl) + 
   tm_lines("black") + 
